# coding=utf-8
from __future__ import print_function

import argparse
import os
import re

import cv2
import numpy as np

from suanpan import path, utils
from suanpan.arguments import Arg, ListOfString, String
from suanpan.components import Result
from suanpan.docker.datawarehouse import dw
from suanpan.docker.io import storage


class HiveTable(Arg):
    def __init__(self, key, table, partition):
        super(HiveTable, self).__init__(key)
        self.table = String(key=table, required=True)
        self.partition = String(key=partition)

    @property
    def isSet(self):
        return True

    def addParserArguments(self, parser):
        self.table.addParserArguments(parser)
        self.partition.addParserArguments(parser)

    def load(self, args):
        self.table.load(args)
        self.partition.load(args)
        self.value = dict(table=self.table.value, partition=self.partition.value)

    def format(self, context):
        self.value = dw.readTable(self.table.value, self.partition.value)
        return self.value

    def save(self, context, result):
        data = result.value
        dw.writeTable(self.table.value, data)


class SeriesRules(ListOfString):
    OPERATORS = {
        ">": np.greater,
        ">=": np.greater_equal,
        "<": np.less,
        "<=": np.less_equal,
    }

    @classmethod
    def transform(cls, item):
        key, operate, value = re.match(r"^(\w+)\s*([<>]=?)\s*(\d+)$", item).groups()
        return {"key": key, "operate": cls.getOperator(operate), "value": float(value)}

    @classmethod
    def getOperator(cls, name):
        return cls.OPERATORS[name]


class LogicalOperator(String):
    LOGICAL_OPERATORS = {
        "and": np.logical_and,
        "or": np.logical_or,
        "xor": np.logical_xor,
        "not": np.logical_not,
    }

    def format(self, context):
        try:
            self.value = self.getLogicalOperator(self.value)
            return self.value
        except:
            argparse.ArgumentTypeError(
                "Unknown logical operator: {}, should in {}".format(
                    self.value, self.LOGICAL_OPERATORS
                )
            )

    @classmethod
    def getLogicalOperator(cls, name):
        return cls.LOGICAL_OPERATORS[name]


class File(String):

    FILENAME = "file"
    FILETYPE = None

    def __init__(self, key, **kwargs):
        fileName = kwargs.pop("name", self.FILENAME)
        fileType = kwargs.pop("type", self.FILETYPE)
        self.fileName = (
            "{}.{}".format(fileName, fileType.lower()) if fileType else fileName
        )
        super(File, self).__init__(key, **kwargs)

    def load(self, args):
        self.objectPrefix = super(File, self).load(args)
        self.objectName = (
            storage.pathJoin(self.objectPrefix, self.fileName) if self.objectPrefix else None
        )
        self.filePath = (
            storage.getPathInTempStore(self.objectName) if self.objectName else None
        )
        if self.filePath:
            path.safeMkdirsForFile(self.filePath)
        self.value = self.filePath
        return self.filePath

    def format(self, context):
        if self.filePath:
            storage.download(self.objectName, self.filePath)
        return self.filePath

    def save(self, context, result):
        filePath = result.value
        storage.upload(self.objectName, filePath)


class Folder(String):
    def load(self, args):
        self.folderName = super(Folder, self).load(args)
        self.folderPath = (
            storage.getPathInTempStore(self.folderName) if self.folderName else None
        )
        if self.folderPath:
            path.safeMkdirs(self.folderPath)
        self.value = self.folderPath
        return self.folderPath

    def format(self, context):
        if self.folderPath:
            storage.download(self.folderName, self.folderPath)
        return self.folderPath

    def save(self, context, result):
        folderPath = result.value
        storage.upload(self.folderName, folderPath)


class Data(File):

    FILENAME = "data"


class Csv(Data):

    FILETYPE = "csv"

    def format(self, context):
        super(Csv, self).format(context)
        self.value = utils.loadFromNpy(self.filePath)
        return self.value

    def save(self, context, result):
        utils.saveAsNpy(self.filePath, result.value)
        super(Csv, self).format(context, Result(value=self.filePath))


class Npy(Data):

    FILETYPE = "npy"

    def format(self, context):
        super(Npy, self).format(context)
        self.value = utils.loadFromNpy(self.filePath)
        return self.value

    def save(self, context, result):
        utils.saveAsNpy(self.filePath, result.value)
        super(Npy, self).format(context, Result(value=self.filePath))

class Model(File):

    FILENAME = "model"


class H5Model(Model):

    FILETYPE = "h5"


class Checkpoint(Model):

    FILETYPE = "ckpt"


class JsonModel(Model):

    FILETYPE = "json"


class Image(File):

    FILENAME = "image"
    FILETYPE = "png"

    def format(self, context):
        filepath = super(Image, self).format(context)
        self.value = cv2.imread(filepath)
        return self.value

    def save(self, context, result):
        img = result.value
        filepath = storage.getPathInTempStore(self.objectName)
        path.safeMkdirsForFile(filepath)
        cv2.imwrite(filepath, img)
        storage.upload(self.objectName, filepath)



# coding=utf-8
from __future__ import division, print_function

import os
import shutil
import zipfile

import time
import oss2
from oss2.resumable import ResumableDownloadStore, ResumableStore

from suanpan import asyncio, path
from suanpan.log import logger


class FrequenceTimeLimiter(object):
    def __init__(self, seconds):
        self.frequence = seconds
        self.time = time.time()

    def ifEnable(self):
        newTime = time.time()
        enable = self.frequence < newTime - self.time
        self.time = newTime if enable else self.time
        return enable


class OssStorage(object):

    DEFAULT_IGNORE_KEYWORDS = {"__MACOSX", ".DS_Store"}
    CONTENT_MD5 = "Content-MD5"

    def __init__(
        self,
        ossAccessId,
        ossAccessKey,
        ossBucketName="suanpan",
        ossEndpoint="http://oss-cn-beijing.aliyuncs.com",
        ossDelimiter="/",
        ossTempStore="/tmp",
        ossDownloadNumThreads=1,
        ossDownloadStoreName=".py-oss-download",
        ossUploadNumThreads=1,
        ossUploadStoreName=".py-oss-upload",
        **kwargs
    ):
        self.accessId = ossAccessId
        self.accessKey = ossAccessKey
        self.bucketName = ossBucketName
        self.endpoint = ossEndpoint

        self.auth = oss2.Auth(self.accessId, self.accessKey)
        self.bucket = self.getBucket(self.bucketName)

        self.delimiter = ossDelimiter
        self.tempStore = ossTempStore

        self.downloadNumThreads = ossDownloadNumThreads
        self.downloadStoreName = ossDownloadStoreName
        self.downloadStore = ResumableDownloadStore(
            self.tempStore, self.downloadStoreName
        )

        self.uploadNumThreads = ossUploadNumThreads
        self.uploadStoreName = ossUploadStoreName
        self.uploadStore = ResumableStore(self.tempStore, self.uploadStoreName)

    def getBucket(self, bucketOrBucketName):
        return (
            bucketOrBucketName
            if isinstance(bucketOrBucketName, oss2.Bucket)
            else self.getBucketByName(bucketOrBucketName)
        )

    def getBucketByName(self, bucketName=None):
        return (
            oss2.Bucket(self.auth, self.endpoint, bucketName)
            if bucketName
            else self.bucket
        )

    def downloadIntoTempStore(
        self,
        name,
        path=None,
        tempStore=None,
        bucketOrBucketName=None,
        ignore=DEFAULT_IGNORE_KEYWORDS,
    ):
        bucket = self.getBucket(bucketOrBucketName)
        path = path or self.localPathJoin(bucket.bucket_name, name)
        path = self.getPathInTempStore(path, tempStore=tempStore)
        return self.download(name, path, bucketOrBucketName=bucket, ignore=ignore)

    def download(
        self, name, path, bucketOrBucketName=None, ignore=DEFAULT_IGNORE_KEYWORDS
    ):
        bucket = self.getBucket(bucketOrBucketName)
        downloadFunction = (
            self.downloadFile
            if self.isFile(name, bucketOrBucketName=bucket)
            else self.downloadFolder
        )
        return downloadFunction(name, path, bucketOrBucketName=bucket, ignore=ignore)

    def downloadFile(
        self,
        objectName,
        filepath,
        bucketOrBucketName=None,
        ignore=DEFAULT_IGNORE_KEYWORDS,
    ):
        bucket = self.getBucket(bucketOrBucketName)
        storagePath = self.storageUrl(bucket, objectName)

        if filepath in ignore:
            logger.info(
                "Ignore downloading file: {} -> {}".format(storagePath, filepath)
            )
            return filepath

        if self.checkMd5(objectName, filepath, bucketOrBucketName=bucket):
            logger.info("Ignore existed file: {} -> {}".format(storagePath, filepath))
            return filepath

        limiter = FrequenceTimeLimiter(seconds=5)

        def _percentage(consumed_bytes, total_bytes):
            if total_bytes and limiter.ifEnable():
                rate = round(consumed_bytes / total_bytes * 100, 2)
                logger.info(
                    "Downloading file: {} -> {} - {}".format(
                        storagePath, filepath, "{}%".format(rate)
                    )
                )

        logger.info("Downloading file: {} -> {}".format(storagePath, filepath))
        path.safeMkdirsForFile((filepath))
        oss2.resumable_download(
            bucket,
            objectName,
            filepath,
            num_threads=self.downloadNumThreads,
            store=self.downloadStore,
            progress_callback=_percentage,
        )
        logger.info("Downloaded file: {} -> {}".format(storagePath, filepath))
        return filepath

    def downloadFolder(
        self,
        folderName,
        folderpath,
        delimiter=None,
        bucketOrBucketName=None,
        workers=None,
        ignore=DEFAULT_IGNORE_KEYWORDS,
    ):
        bucket = self.getBucket(bucketOrBucketName)
        delimiter = delimiter or self.delimiter
        storagePath = self.storageUrl(bucket, folderName)

        if folderpath in ignore:
            logger.info(
                "Ignore downloading folder: {} -> {}".format(folderpath, storagePath)
            )
            return folderpath

        logger.info("Downloading folder: {} -> {}".format(storagePath, folderpath))
        with asyncio.multiThread(workers) as pool:
            for _, _, files in self.walk(
                folderName, delimiter=delimiter, bucketOrBucketName=bucket
            ):
                for file in files:
                    filepath = self.localPathJoin(
                        folderpath, self.ossRelativePath(file, folderName)
                    )
                    pool.apply_async(
                        self.downloadFile,
                        args=(file, filepath),
                        kwds={"bucketOrBucketName": bucket, "ignore": ignore},
                    )
        self.removeIgnore(folderpath, ignore=ignore)
        logger.info("Downloaded folder: {} -> {}".format(storagePath, folderpath))
        return folderpath

    def uploadFromTempStore(
        self,
        name,
        path=None,
        tempStore=None,
        bucketOrBucketName=None,
        ignore=DEFAULT_IGNORE_KEYWORDS,
    ):
        bucket = self.getBucket(bucketOrBucketName)
        path = path or self.localPathJoin(bucket.bucket_name, name)
        path = self.getPathInTempStore(path, tempStore=tempStore)
        return self.upload(name, path, bucketOrBucketName=bucket, ignore=ignore)

    def upload(
        self, name, path, bucketOrBucketName=None, ignore=DEFAULT_IGNORE_KEYWORDS
    ):
        bucket = self.getBucket(bucketOrBucketName)
        uploadFunction = self.uploadFolder if os.path.isdir(path) else self.uploadFile
        return uploadFunction(name, path, bucketOrBucketName=bucket, ignore=ignore)

    def uploadFile(
        self,
        objectName,
        filepath,
        bucketOrBucketName=None,
        ignore=DEFAULT_IGNORE_KEYWORDS,
    ):
        bucket = self.getBucket(bucketOrBucketName)
        storagePath = self.storageUrl(bucket, objectName)

        if filepath in ignore:
            logger.info("Ignore uploading file: {} -> {}".format(filepath, storagePath))
            return filepath

        fileMd5 = path.md5(filepath)
        if self.getMd5(objectName, bucketOrBucketName=bucket) == fileMd5:
            logger.info("Ignore existed file: {} -> {}".format(filepath, storagePath))
            return filepath

        limiter = FrequenceTimeLimiter(seconds=5)

        def _percentage(consumed_bytes, total_bytes):
            if total_bytes and limiter.ifEnable():
                rate = round(consumed_bytes / total_bytes * 100, 2)
                logger.info(
                    "Uploading file: {} -> {} - {}".format(
                        filepath, storagePath, "{}%".format(rate)
                    )
                )

        logger.info("Uploading file: {} -> {}".format(filepath, storagePath))
        oss2.resumable_upload(
            bucket,
            objectName,
            filepath,
            num_threads=self.uploadNumThreads,
            store=self.uploadStore,
            progress_callback=_percentage,
            headers={self.CONTENT_MD5: fileMd5},
        )
        logger.info("Uploaded file: {} -> {}".format(filepath, storagePath))
        return filepath

    def uploadFolder(
        self,
        folderName,
        folderpath,
        bucketOrBucketName=None,
        workers=None,
        ignore=DEFAULT_IGNORE_KEYWORDS,
    ):
        bucket = self.getBucket(bucketOrBucketName)
        storagePath = self.storageUrl(bucket, folderName)

        if folderName in ignore:
            logger.info(
                "Ignore uploading folder: {} -> {}".format(folderName, storagePath)
            )
            return folderpath

        logger.info("Uploading folder: {} -> {}".format(folderpath, storagePath))
        with asyncio.multiThread(workers) as pool:
            for root, _, files in os.walk(folderpath):
                for file in files:
                    filepath = os.path.join(root, file)
                    objectName = self.ossPathJoin(
                        folderName, self.localRelativePath(filepath, folderpath)
                    )
                    pool.apply_async(
                        self.uploadFile,
                        args=(objectName, filepath),
                        kwds={"bucketOrBucketName": bucket, "ignore": ignore},
                    )
        logger.info("Uploaded folder: {} -> {}".format(folderpath, storagePath))
        return folderpath

    def walk(self, folderName, delimiter=None, bucketOrBucketName=None):
        bucket = self.getBucket(bucketOrBucketName)
        delimiter = delimiter or self.delimiter
        root = folderName if folderName.endswith(delimiter) else folderName + delimiter
        folders = []
        files = []
        for obj in oss2.ObjectIterator(bucket, delimiter=delimiter, prefix=root):
            array = folders if obj.is_prefix() else files
            array.append(obj.key)
        if not folders and not files:
            storagePath = self.storageUrl(bucket, root)
            raise Exception("Oss Error: No such folder: {}".format(storagePath))
        yield root, folders, files
        for folder in folders:
            for item in self.walk(
                folder, delimiter=delimiter, bucketOrBucketName=bucket
            ):
                yield item

    def listAll(self, folderName, delimiter=None, bucketOrBucketName=None):
        bucket = self.getBucket(bucketOrBucketName)
        delimiter = delimiter or self.delimiter
        prefix = (
            folderName if folderName.endswith(delimiter) else folderName + delimiter
        )
        return (
            obj
            for obj in oss2.ObjectIterator(
                delimiter=delimiter, prefix=prefix, bucket=bucket
            )
        )

    def listFolders(self, folderName, delimiter=None, bucketOrBucketName=None):
        bucket = self.getBucket(bucketOrBucketName)
        delimiter = delimiter or self.delimiter
        return (
            obj
            for obj in self.listAll(
                folderName, delimiter=delimiter, bucketOrBucketName=bucket
            )
            if obj.is_prefix()
        )

    def listFiles(self, folderName, delimiter=None, bucketOrBucketName=None):
        bucket = self.getBucket(bucketOrBucketName)
        delimiter = delimiter or self.delimiter
        return (
            obj
            for obj in self.listAll(
                folderName, delimiter=delimiter, bucketOrBucketName=bucket
            )
            if not obj.is_prefix()
        )

    def isFile(self, objectName, bucketOrBucketName=None):
        bucket = self.getBucket(bucketOrBucketName)
        return bucket.object_exists(objectName)

    def isFolder(self, folderName, bucketOrBucketName=None):
        bucket = self.getBucket(bucketOrBucketName)
        return next(self.listAll(folderName, bucketOrBucketName=bucket), None)

    def getPathInTempStore(self, path, tempStore=None):
        tempStore = tempStore or self.tempStore
        return self.localPathJoin(tempStore, path)

    def toLocalPath(self, objectName, delimiter=None):
        delimiter = delimiter or self.delimiter
        return objectName.replace(delimiter, os.sep)

    def toOssPath(self, path, delimiter=None):
        delimiter = delimiter or self.delimiter
        return path.replace(os.sep, delimiter)

    def localPathJoin(self, *paths):
        path = os.path.join(*paths)
        return self.toLocalPath(path)

    def ossPathJoin(self, *paths):
        path = os.path.join(*paths)
        return self.toOssPath(path)

    def pathJoin(self, *paths, **kwargs):
        mode = kwargs.get("mode", "oss")
        return self.ossPathJoin(*paths) if mode == "oss" else self.localPathJoin(*paths)

    def localRelativePath(self, path, base):
        return self.relativePath(path, base, delimiter=os.sep)

    def ossRelativePath(self, path, base, delimiter=None):
        delimiter = delimiter or self.delimiter
        return self.relativePath(path, base, delimiter=delimiter)

    def relativePath(self, path, base, delimiter):
        base = base if base.endswith(delimiter) else base + delimiter
        return path[len(base) :] if path.startswith(base) else path

    def compress(self, zipFilePath, path, ignore=DEFAULT_IGNORE_KEYWORDS):
        compressFunc = self.compressFolder if os.path.isdir(path) else self.compressFile
        return compressFunc(zipFilePath, path)

    def compressFolder(self, zipFilePath, folderpath, ignore=DEFAULT_IGNORE_KEYWORDS):
        if folderpath in ignore:
            logger.info(
                "Ignore compressing folder: {} -> {}".format(folderpath, zipFilePath)
            )
            return zipFilePath

        logger.info("Compressing folder: {} -> {}".format(folderpath, zipFilePath))
        with zipfile.ZipFile(zipFilePath, "w") as zip:
            for root, _, files in os.walk(folderpath):
                for file in files:
                    filepath = os.path.join(root, file)
                    zip.write(
                        filepath, arcname=self.localRelativePath(filepath, folderpath)
                    )
        logger.info("Compressed folder: {} -> {}".format(folderpath, zipFilePath))
        return zipFilePath

    def compressFile(self, zipFilePath, filepath, ignore=DEFAULT_IGNORE_KEYWORDS):
        if filepath in ignore:
            logger.info(
                "Ignore compressing File: {} -> {}".format(filepath, zipFilePath)
            )
            return zipFilePath

        logger.info("Compressing File: {} -> {}".format(filepath, zipFilePath))
        with zipfile.ZipFile(zipFilePath, "w") as zip:
            _, filename = os.path.split(filepath)
            zip.write(filepath, arcname=filename)
        logger.info("Compressed File: {} -> {}".format(filepath, zipFilePath))
        return zipFilePath

    def extract(self, zipFilePath, distPath, ignore=DEFAULT_IGNORE_KEYWORDS):
        logger.info("Extracting zip: {} -> {}".format(zipFilePath, distPath))
        with zipfile.ZipFile(zipFilePath, "r") as zip:
            zip.extractall(distPath)
        self.removeIgnore(distPath, ignore=ignore)
        logger.info("Extracted zip: {} -> {}".format(zipFilePath, distPath))

    def remove(self, objectName, delimiter=None, bucketOrBucketName=None):
        delimiter = delimiter or self.delimiter
        bucket = self.getBucket(bucketOrBucketName)
        removeFunc = (
            self.removeFile
            if self.isFile(objectName, bucketOrBucketName=bucket)
            else self.removeFolder
        )
        removeFunc(objectName, delimiter=delimiter, bucketOrBucketName=bucket)

    def removeFile(self, fileName, delimiter=None, bucketOrBucketName=None):
        bucket = self.getBucket(bucketOrBucketName)
        bucket.delete_object(fileName)
        storagePath = self.storageUrl(bucket, fileName)
        logger.info("Removed File: {}".format(storagePath))

    def removeFolder(self, folderName, delimiter=None, bucketOrBucketName=None):
        delimiter = delimiter or self.delimiter
        bucket = self.getBucket(bucketOrBucketName)
        folderName = (
            folderName + delimiter if not folderName.endswith(delimiter) else folderName
        )
        for obj in oss2.ObjectIterator(bucket, delimiter=delimiter, prefix=folderName):
            if not obj.is_prefix():
                self.removeFile(obj.key, delimiter=delimiter, bucketOrBucketName=bucket)
            else:
                self.removeFolder(
                    obj.key, delimiter=delimiter, bucketOrBucketName=bucket
                )
        storagePath = self.storageUrl(bucket, folderName)
        logger.info("Removed Folder: {}".format(storagePath))

    def storageUrl(self, bucket, path):
        return "oss:///" + self.ossPathJoin(bucket.bucket_name, path)

    def removeIgnore(self, path, ignore=DEFAULT_IGNORE_KEYWORDS):
        def _ignore(_root, _path):
            if _path in ignore:
                _path = os.path.join(_root, _path)
                if os.path.isfile(_path):
                    os.remove(_path)
                    logger.info("Removed ignore file: {}".format(_path))
                else:
                    shutil.rmtree(_path)
                    logger.info("Removed ignore folder: {}".format(_path))

        for root, folders, files in os.walk(path):
            for folder in folders:
                _ignore(root, folder)
            for file in files:
                _ignore(root, file)

    def getMd5(self, objectName, bucketOrBucketName=None):
        bucket = self.getBucket(bucketOrBucketName)
        try:
            return bucket.head_object(objectName).headers.get(self.CONTENT_MD5)
        except:
            return None

    def checkMd5(self, objectName, filePath, bucketOrBucketName=None):
        if not os.path.isfile(filePath):
            return False

        bucket = self.getBucket(bucketOrBucketName)
        return self.getMd5(objectName, bucketOrBucketName=bucket) == path.md5(filePath)



# coding=utf-8
from __future__ import print_function

import argparse
import itertools
import time
import traceback
import uuid
from concurrent import futures

import grpc

from suanpan import asyncio
from suanpan.arguments import Int
from suanpan.log import logger
from suanpan.services import common_pb2, common_pb2_grpc


class Service(common_pb2_grpc.CommonServicer):

    defaultServiceCall = "call"
    defaultArguments = [
        Int("port", default=8980),
        Int("workers", default=asyncio.WORKERS),
    ]
    arguments = []

    def __init__(self):
        logger.setLogger(self.name)
        self.args = self.parseArgs()

    @property
    def name(self):
        return self.__class__.__name__

    def generateRequestId(self):
        return uuid.uuid4().hex

    def formatMessage(self, request, msg):
        return "{} - {} - {}".format(
            request.id, request.type or self.defaultServiceCall, msg
        )

    def predict(self, request, context):
        try:
            logger.info(self.formatMessage(request, msg="Start"))
            callFunction = self.getCallFunction(request, context)
            outputs = callFunction(request, context) or {}
            result = dict(success=True, **outputs)
            logger.info(self.formatMessage(request, msg="Done"))
        except:
            tracebackInfo = traceback.format_exc()
            result = dict(success=False, msg=tracebackInfo)
            logger.error(self.formatMessage(request, msg=tracebackInfo))
        finally:
            return common_pb2.Response(request_id=request.id, **result)

    def getCallFunction(self, request, context):
        serviceCall = request.type or self.defaultServiceCall
        callFunction = getattr(self, serviceCall, None)
        if not callFunction:
            raise Exception(
                "Unknown service call: {}.{}".format(self.name, serviceCall)
            )
        return callFunction

    def call(self, request, context, *args):
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def parseArguments(self, arguments, description=""):
        parser = argparse.ArgumentParser(description=description)
        for arg in arguments:
            arg.addParserArguments(parser)
        return parser.parse_known_args()[0]

    def parseArgs(self):
        return self.parseArguments(itertools.chain(self.defaultArguments, self.arguments))

    def start(self):
        server = grpc.server(futures.ThreadPoolExecutor(max_workers=self.args.workers))
        common_pb2_grpc.add_CommonServicer_to_server(self, server)
        server.add_insecure_port("[::]:{}".format(self.args.port))
        server.start()
        logger.info("{} started!".format(self.name))
        try:
            _ONE_DAY_IN_SECONDS = 60 * 60 * 24
            while True:
                time.sleep(_ONE_DAY_IN_SECONDS)
        except KeyboardInterrupt:
            server.stop(0)



# coding=utf-8
from __future__ import print_function

from suanpan.docker.datawarehouse.hive import HiveDataWarehouse
from suanpan.proxy import Proxy


class DataWarehouseProxy(Proxy):
    MAPPING = {"hive": HiveDataWarehouse}


dw = DataWarehouseProxy()



#!/usr/bin/env python

"""
suanpan
"""
import os

from setuptools import find_packages, setup

INSTALL_REQUIRES = [
    "imageio==2.4.1",
    "numpy==1.15.2",
    "opencv-python==3.4.3.18",
    "pandas==0.23.4",
]
EXTRAS_REQUIRE = {
    "service": [
        "googleapis-common-protos==1.6.0b6",
        "grpcio-tools==1.16.1rc1",
        "sasl==0.2.1",
        "thrift-sasl==0.3.0",
        "thrift==0.11.0",
        "pyhive[hive]==0.6.1",
    ],
    "docker": [
        "oss2==2.5.0",
        "sasl==0.2.1",
        "thrift-sasl==0.3.0",
        "thrift==0.11.0",
        "pyhive[hive]==0.6.1",
    ]
}
README = "README.md"


def read_file(path):
    with open(path, "r") as f:
        return f.read()

setup(
    name="suanpan",
    version="0.3.9",
    packages=find_packages(),
    license="See License",
    author="majik",
    author_email="me@yamajik.com",
    description=read_file(README),
    long_description=__doc__,
    zip_safe=False,
    include_package_data=True,
    platforms="any",
    install_requires=INSTALL_REQUIRES,
    extras_require=EXTRAS_REQUIRE,
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
